@@ -3,7 +3,12 @@ The :mod:`ramp_frontend.utils` provides utilities to ease sending email.
 """
 
 import logging
+from concurrent.futures import ThreadPoolExecutor
 
+from flask import (
+    copy_current_request_context,
+    current_app,
+)
 from flask_mail import Message
 
 from ramp_frontend import mail
@@ -11,6 +16,23 @@ from ramp_frontend import mail
 logger = logging.getLogger("RAMP-FRONTEND")
 
 
+def ensure_threadpoolexecutor_is_running(pool):
+    """Ensure that the threadpool executor is running.
+
+    Parameters
+    ----------
+    pool : :class:`concurrent.futures.ThreadPoolExecutor`
+        The threadpool executor.
+    """
+    try:
+        pool.submit(lambda: None)
+        return pool
+    except RuntimeError:
+        logger.info("Threadpool executor is not running")
+        pool.shutdown(wait=False)
+        return ThreadPoolExecutor(max_workers=pool._max_workers)
+
+
 def body_formatter_user(user):
     """Create the body of an email using the user information.
 
@@ -63,10 +85,17 @@ def send_mail(to, subject, body):
     body : str
         The body of the email.
     """
-    try:
-        msg = Message(subject)
-        msg.body = body
-        msg.add_recipient(to)
-        mail.send(msg)
-    except Exception as e:
-        logger.error("Mailing error: {}".format(e))
+    msg = Message(subject)
+    msg.body = body
+    msg.add_recipient(to)
+
+    @copy_current_request_context
+    def send(msg):
+        try:
+            mail.send(msg)
+        except Exception as e:
+            logger.error(f"Mailing error: {e}")
+        return "Successfully sent email"
+
+    current_app.pool = ensure_threadpoolexecutor_is_running(current_app.pool)
+    current_app.pool.submit(send, msg)
